flow-texpack is a program that will allow you to generate texture atlas from input images (BMP,
HDR, JPG, PNG, TGA, TIFF, WEBP). The application generates both texture atlas and descriptions
file that can be read by a game.
Usage
Show available options:
flow-texpack -hor
flow-texpack --helpExamples
Generate from input data/characters and data/tiles, write output to out/atlas and enable
the options: premultiply pixels by their alpha channel, trim excess transparency off the
textures, remove duplicate textures from the atlas, enable rotation of textures 90 degrees
clockwise, pad each texture by 2 pixels and finally enable verbose output mode.
flow-texpack -i data/characters data/tiles -o out/atlas -m -t -u -r -p 2 -vEnable load filter so that only TGA images are included in the texture atlas:
flow-texpack -i data/tiles -o out/atlas --load-filter tga -vEnable rect heuristic AreaFit:
flow-texpack -i data/tiles -o out/atlas --rect-heuristic area-fit -vEnable output atlas size of 2048x2048:
flow-texpack -i data/tiles -o out/atlas --atlas-size pot2048 -vRead input files/directories from input.txt but exclude all in exclude.txt:
flow-texpack --input-file input.txt --exlude-file exclude.txt -o out/atlas -vAdjust atlas size automatically so that texture will fit:
flow-texpack -i data/characters -o out/atlas --adjust-size -vAdjust texture size so that it will fit given atlas size:
flow-texpack -i data/characters -o out/atlas --adjust-fit -v